@@ -359,8 +359,8 @@ class Node(threading.Thread):
         except Exception as e:
             print(e)
 
-    def send_my_block(self, nodes):
-        system = GetBlock()
+    def send_my_block(self, block, nodes):
+        system = block
 
         new_list = []
 
@@ -391,8 +391,8 @@ class Node(threading.Thread):
         for each_node in nodes:
             self.send_data_to_node(each_node, data)
 
-    def send_my_block_hash(self, nodes):
-        system = GetBlock()
+    def send_my_block_hash(self, block, nodes):
+        system = block
 
         if system.raund_1 and not system.raund_2:
 
@@ -414,48 +414,51 @@ class Node(threading.Thread):
                 self.send_data_to_node(each_node, data)
 
     def get_candidate_block(self, data, node):
+        if node.candidate_block is None:
 
-        if (Unl.node_is_unl(node.id)
-                and GetBlock().sequance_number == data["sequance_number"]):
-
-            signature_list = []
-            for element in data["transaction"]:
-                signature_list.append(element["signature"])
-
-            merkle_root_of_signature_list = (
-                MerkleTree(signature_list).getRootHash()
-                if len(signature_list) != 0 else "0")
-
-            if Ecdsa.verify(
-                    "myblock" + merkle_root_of_signature_list +
-                    str(data["sequance_number"]),
-                    Signature.fromBase64(data["signature"]),
-                    PublicKey.fromPem(node.id),
-            ):
-
-                temp_tx = []
+            if (Unl.node_is_unl(node.id)
+                    and GetBlock().sequance_number == data["sequance_number"]):
 
+                signature_list = []
                 for element in data["transaction"]:
-                    temp_tx.append(Transaction.load_json(element))
+                    signature_list.append(element["signature"])
 
-                data["transaction"] = temp_tx
+                merkle_root_of_signature_list = (
+                    MerkleTree(signature_list).getRootHash()
+                    if len(signature_list) != 0 else "0")
 
-                node.candidate_block = data
+                if Ecdsa.verify(
+                        "myblock" + merkle_root_of_signature_list +
+                        str(data["sequance_number"]),
+                        Signature.fromBase64(data["signature"]),
+                        PublicKey.fromPem(node.id),
+                ):
+
+                    temp_tx = []
+
+                    for element in data["transaction"]:
+                        temp_tx.append(Transaction.load_json(element))
+
+                    data["transaction"] = temp_tx
+
+                    node.candidate_block = data
 
     def get_candidate_block_hash(self, data, node):
 
-        if (Unl.node_is_unl(node.id)
-                and GetBlock().sequance_number == data["sequance_number"]):
+        if node.candidate_block_hash is None:
 
-            if Ecdsa.verify(
-                    "myblockhash" + data["hash"] +
-                    str(data["sequance_number"]),
-                    Signature.fromBase64(data["signature"]),
-                    PublicKey.fromPem(node.id),
-            ):
-                data["sender"] = node.id
+            if (Unl.node_is_unl(node.id)
+                    and GetBlock().sequance_number == data["sequance_number"]):
 
-                node.candidate_block_hash = data
+                if Ecdsa.verify(
+                        "myblockhash" + data["hash"] +
+                        str(data["sequance_number"]),
+                        Signature.fromBase64(data["signature"]),
+                        PublicKey.fromPem(node.id),
+                ):
+                    data["sender"] = node.id
+
+                    node.candidate_block_hash = data
 
     def send_full_chain(self, node=None):
         file = open(TEMP_BLOCK_PATH, "rb")
